@@ -20,19 +20,18 @@ class display_client_detail(DetailView):
 
         client = models.xsanio_client.objects.get(pk=self.kwargs['pk'])
         for stat_type in models.stat_type.objects.all():
-            client_stat_entries = models.stat_entry.objects.filter(
+            client_stat_entry = models.stat_entry.objects.filter(
                 host=client,
                 type=stat_type,
             ).latest()
 
-            for client_stat_entry in client_stat_entries:
-                disk_name = client_stat_entry.disk
+            disk_name = client_stat_entry.disk
 
-                if disk_name not in disks_iodata:
-                    disks_iodata[disk_name] = {}
+            if disk_name not in disks_iodata:
+                disks_iodata[disk_name] = {}
 
-                disk_iodata = disks_iodata[disk_name]
-                disk_iodata[stat_type.name] = client_stat_entry.value
+            disk_iodata = disks_iodata[disk_name]
+            disk_iodata[stat_type.name] = client_stat_entry.value
 
         disks_iodata_array = []
         for disk_name in disks_iodata:
